@@ -45,8 +45,10 @@ def GetBytes(dev,HV_Ref,DAC_Ref,T_Ref,MaxNumBit=1000000,TC=True):
         Bytes=dev.read(A[0])
         BitRead=BitRead+len(Bytes)*8
         BytesReturn.append(Bytes)
+        BytesReturn_Pre=BytesReturn[0]
+        BytesReturn=BytesReturn_Pre[0:MaxNumBit]
 
-    return BytesReturn[0:MaxNumBit]
+    return BytesReturn
 
 
 def GetBits(dev,HV_Ref,DAC_Ref,T_Ref,MaxNumBit=1000000,TC=True):
@@ -79,6 +81,7 @@ def GetBits(dev,HV_Ref,DAC_Ref,T_Ref,MaxNumBit=1000000,TC=True):
         Aux=Hex.HexToBit(Bytes.hex())
         BitRead=BitRead+len(Aux)
         BitsReturn.append(Aux)
-
-    return BitsReturn[0:MaxNumBit]
+        BitsReturn_pre=BitsReturn[0]
+        BitsReturn=BitsReturn_pre[0:MaxNumBit]
+    return BitsReturn
         
